%% Computing number of turns for NFC PCB coil in non-magnetic material
L = 1.91e-6;    % inductivity in Henry
w = 0.2e-3;     % width of line in meter
g = 0.4e-3;     % width of line in meter
Ro = 11e-3;     % maximum outer radius in meter
%%%%%%%%%%%%%
K1 = 2.23;
K2 = 3.45;
mu0 = 4*pi*1e-7;

Do = 2*Ro;
A = (w+g)^2*K1*mu0;
B = -2*K1*mu0*Do*(w+g);
C = K1*mu0*Do^2;
D = L*(w+g)*(1-K2);
E = -L*Do;

alpha = (-3*B^2/8/A^2)+(C/A);
beta = (B^3/8/A^3)-(B*C/2/A^2) + (D/A);
gam = (-3*B^4/256/A^4) + (C*B^2/16/A^3) - (B*D/4/A^2) + (E/A);

P = -alpha^2/12-gam;
Q = -alpha^3/108 + (alpha*gam/3) - beta^2/8;
R = -Q/2+sqrt(Q^2/4+P^3/27);

U = R^(1/3);

if U == 0
    y = -5/6*alpha-(Q)^(1/3);
else
    y = -5/6*alpha+U-(P/3/U);
end
W = sqrt(alpha+2*y);

N1 = -B/4/A + W/2 + sqrt(-(3*alpha+2*y + 2*beta/W))/2;
N2 = -B/4/A - W/2 + sqrt(-(3*alpha+2*y - 2*beta/W))/2;
N3 = -B/4/A + W/2 - sqrt(-(3*alpha+2*y + 2*beta/W))/2;
N4 = -B/4/A - W/2 - sqrt(-(3*alpha+2*y - 2*beta/W))/2;

% A*N1^4+B*N1^3+C*N1^2+D*N1+E;
% A*N2^4+B*N2^3+C*N2^2+D*N2+E;
% A*N3^4+B*N3^3+C*N3^2+D*N3+E;
% A*N4^4+B*N4^3+C*N4^2+D*N4+E;

N = [N1;N2;N3;N4];

EntriestEliminate = abs(imag(N)) > 1e-10;
N(EntriestEliminate) = [];
N = real(N);
N(N<0) = [];
FinalN = min(N);
disp(['Number of turns of the NFC PCB coil should be: ',num2str(FinalN)])
